@@ -1,14 +1,13 @@
 #!/usr/bin/env python
 #
 # Author: Mike McKerns (mmckerns @caltech and @uqfoundation)
-# Copyright (c) 2018-2023 The Uncertainty Quantification Foundation.
+# Copyright (c) 2018-2026 The Uncertainty Quantification Foundation.
 # License: 3-clause BSD.  The full license text is available at:
 #  - https://github.com/uqfoundation/dill/blob/master/LICENSE
 """
 to run this test suite, first build and install `dill`.
 
-  $ python setup.py build
-  $ python setup.py install
+  $ python -m pip install ../..
 
 
 then run the tests with:
